--- a/xpdf/pdfimages.cc
+++ b/xpdf/pdfimages.cc
@@ -4,6 +4,8 @@
 //
 // Copyright 1998-2003 Glyph & Cog, LLC
 //
+// Modified for Debian by Hamish Moffatt, 22 May 2002.
+//
 //========================================================================
 
 #include <aconf.h>
@@ -127,12 +129,14 @@ int main(int argc, char *argv[]) {
   }
 
   // check for copy permission
+#ifdef ENFORCE_PERMISSIONS
   if (!doc->okToCopy()) {
     error(errNotAllowed, -1,
 	  "Copying of images from this document is not allowed.");
     exitCode = 3;
     goto err1;
   }
+#endif
 
   // get page range
   if (firstPage < 1)
--- a/xpdf/pdftohtml.cc
+++ b/xpdf/pdftohtml.cc
@@ -138,6 +138,7 @@ int main(int argc, char *argv[]) {
     goto err1;
   }
 
+#ifdef ENFORCE_PERMISSIONS
   // check for copy permission
   if (!doc->okToCopy()) {
     error(errNotAllowed, -1,
@@ -145,6 +146,7 @@ int main(int argc, char *argv[]) {
     exitCode = 3;
     goto err1;
   }
+#endif
 
   // get page range
   if (firstPage < 1) {
--- a/xpdf/pdftops.cc
+++ b/xpdf/pdftops.cc
@@ -4,6 +4,8 @@
 //
 // Copyright 1996-2003 Glyph & Cog, LLC
 //
+// Modified for Debian by Hamish Moffatt, 22 May 2002.
+//
 //========================================================================
 
 #include <aconf.h>
@@ -318,12 +320,14 @@ int main(int argc, char *argv[]) {
     goto err1;
   }
 
+#ifdef ENFORCE_PERMISSIONS
   // check for print permission
   if (!doc->okToPrint()) {
     error(errNotAllowed, -1, "Printing this document is not allowed.");
     exitCode = 3;
     goto err1;
   }
+#endif
 
   // construct PostScript file name
   if (argc == 3) {
--- a/xpdf/pdftotext.cc
+++ b/xpdf/pdftotext.cc
@@ -4,6 +4,8 @@
 //
 // Copyright 1997-2013 Glyph & Cog, LLC
 //
+// Modified for Debian by Hamish Moffatt, 22 May 2002.
+//
 //========================================================================
 
 #include <aconf.h>
@@ -209,6 +211,7 @@ int main(int argc, char *argv[]) {
     goto err2;
   }
 
+#ifdef ENFORCE_PERMISSIONS
   // check for copy permission
   if (!doc->okToCopy()) {
     error(errNotAllowed, -1,
@@ -216,6 +219,7 @@ int main(int argc, char *argv[]) {
     exitCode = 3;
     goto err2;
   }
+#endif
 
   // construct text file name
   if (argc == 3) {
--- a/xpdf-qt/QtPDFCore.cc
+++ b/xpdf-qt/QtPDFCore.cc
@@ -446,9 +446,11 @@ QString QtPDFCore::getSelectedTextQStrin
   QString qs;
   int i;
 
+#ifdef ENFORCE_PERMISSIONS
   if (!doc->okToCopy()) {
     return "";
   }
+#endif
   if (!(s = getSelectedText())) {
     return "";
   }
--- a/xpdf-qt/XpdfWidget.cc
+++ b/xpdf-qt/XpdfWidget.cc
@@ -1440,7 +1440,11 @@ bool XpdfWidget::okToExtractText() const
     if (!core->getDoc()) {
       return false;
     }
+#ifdef ENFORCE_PERMISSIONS
     return (bool)core->getDoc()->okToCopy();
+#else
+    return true;
+#endif
   } catch (GMemException e) {
     return false;
   }
